@@ -23,9 +23,9 @@
 from ufl.log import error
 from ufl.utils.str import as_native_strings
 from ufl.core.ufl_type import ufl_type
-from ufl.core.expr import Expr, ufl_err_str
+from ufl.core.expr import ufl_err_str
 from ufl.core.operator import Operator
-from ufl.constantvalue import Zero, zero, ScalarValue, IntValue, as_ufl
+from ufl.constantvalue import Zero, zero, ScalarValue, IntValue, ComplexValue, as_ufl
 from ufl.checks import is_ufl_scalar, is_true_ufl_scalar
 from ufl.index_combination_utils import merge_unique_indices
 from ufl.sorting import sorted_expr
@@ -110,7 +110,7 @@ class Sum(Operator):
             n = len(s)
             for o in ops[1:]:
                 m = len(o)
-                if n+m > limit:
+                if n + m > limit:
                     s += delimop
                     n = m
                 else:
@@ -242,7 +242,10 @@ class Division(Operator):
         # Simplification "literal a / literal b" -> "literal value of
         # a/b". Avoiding integer division by casting to float
         if isinstance(a, ScalarValue) and isinstance(b, ScalarValue):
-            return as_ufl(float(a._value) / float(b._value))
+            try:
+                return as_ufl(float(a._value) / float(b._value))
+            except TypeError:
+                return as_ufl(complex(a._value) / complex(b._value))
         # Simplification "a / a" -> "1"
         # if not a.ufl_free_indices and not a.ufl_shape and a == b:
         #    return as_ufl(1)
@@ -265,7 +268,11 @@ class Division(Operator):
         a = a.evaluate(x, mapping, component, index_values)
         b = b.evaluate(x, mapping, component, index_values)
         # Avoiding integer division by casting to float
-        return float(a) / float(b)
+        try:
+            e = float(a) / float(b)
+        except TypeError:
+            e = complex(a) / complex(b)
+        return e
 
     def __str__(self):
         return "%s / %s" % (parstr(self.ufl_operands[0], self),
@@ -292,7 +299,11 @@ class Power(Operator):
         # Simplification
         if isinstance(a, ScalarValue) and isinstance(b, ScalarValue):
             return as_ufl(a._value ** b._value)
+        if isinstance(b, Zero):
+            return IntValue(1)
         if isinstance(a, Zero) and isinstance(b, ScalarValue):
+            if isinstance(b, ComplexValue):
+                error("Cannot raise zero to a complex power.")
             bf = float(b)
             if bf < 0:
                 error("Division by zero, cannot raise 0 to a negative power.")
@@ -300,8 +311,6 @@ class Power(Operator):
                 return zero()
         if isinstance(b, ScalarValue) and b._value == 1:
             return a
-        if isinstance(b, Zero):
-            return IntValue(1)
 
         # Construction
         self = Operator.__new__(cls)
@@ -333,10 +342,21 @@ class Power(Operator):
 class Abs(Operator):
     __slots__ = ()
 
+    def __new__(cls, a):
+        a = as_ufl(a)
+
+        # Simplification
+        if isinstance(a, (Zero, Abs)):
+            return a
+        if isinstance(a, Conj):
+            return Abs(a.ufl_operands[0])
+        if isinstance(a, ScalarValue):
+            return as_ufl(abs(a._value))
+
+        return Operator.__new__(cls)
+
     def __init__(self, a):
         Operator.__init__(self, (a,))
-        if not isinstance(a, Expr):
-            error("Expecting Expr instance, not %s." % ufl_err_str(a))
 
     def evaluate(self, x, mapping, component, index_values):
         a = self.ufl_operands[0].evaluate(x, mapping, component, index_values)
@@ -345,3 +365,95 @@ class Abs(Operator):
     def __str__(self):
         a, = self.ufl_operands
         return "|%s|" % (parstr(a, self),)
+
+
+@ufl_type(num_ops=1,
+          inherit_shape_from_operand=0, inherit_indices_from_operand=0)
+class Conj(Operator):
+    __slots__ = ()
+
+    def __new__(cls, a):
+        a = as_ufl(a)
+
+        # Simplification
+        if isinstance(a, (Abs, Real, Imag, Zero)):
+            return a
+        if isinstance(a, Conj):
+            return a.ufl_operands[0]
+        if isinstance(a, ScalarValue):
+            return as_ufl(a._value.conjugate())
+
+        return Operator.__new__(cls)
+
+    def __init__(self, a):
+        Operator.__init__(self, (a,))
+
+    def evaluate(self, x, mapping, component, index_values):
+        a = self.ufl_operands[0].evaluate(x, mapping, component, index_values)
+        return a.conjugate()
+
+    def __str__(self):
+        a, = self.ufl_operands
+        return "conj(%s)" % (parstr(a, self),)
+
+
+@ufl_type(num_ops=1,
+          inherit_shape_from_operand=0, inherit_indices_from_operand=0)
+class Real(Operator):
+    __slots__ = ()
+
+    def __new__(cls, a):
+        a = as_ufl(a)
+
+        # Simplification
+        if isinstance(a, Conj):
+            a = a.ufl_operands[0]
+        if isinstance(a, Zero):
+            return a
+        if isinstance(a, ScalarValue):
+            return as_ufl(a.real())
+        if isinstance(a, Real):
+            a = a.ufl_operands[0]
+
+        return Operator.__new__(cls)
+
+    def __init__(self, a):
+        Operator.__init__(self, (a,))
+
+    def evaluate(self, x, mapping, component, index_values):
+        a = self.ufl_operands[0].evaluate(x, mapping, component, index_values)
+        return a.real
+
+    def __str__(self):
+        a, = self.ufl_operands
+        return "Re[%s]" % (parstr(a, self),)
+
+
+@ufl_type(num_ops=1,
+          inherit_shape_from_operand=0, inherit_indices_from_operand=0)
+class Imag(Operator):
+    __slots__ = ()
+
+    def __new__(cls, a):
+        a = as_ufl(a)
+
+        # Simplification
+        if isinstance(a, Zero):
+            return a
+        if isinstance(a, (Real, Imag, Abs)):
+            return Zero(a.ufl_shape, a.ufl_free_indices, a.ufl_index_dimensions)
+        if isinstance(a, ScalarValue):
+            return as_ufl(a.imag())
+
+        return Operator.__new__(cls)
+
+    def __init__(self, a):
+        Operator.__init__(self, (a,))
+
+    def evaluate(self, x, mapping, component, index_values):
+        a = self.ufl_operands[0].evaluate(x, mapping, component, index_values)
+        return a.imag
+
+    def __str__(self):
+        a, = self.ufl_operands
+        return "Im[%s]" % (parstr(a, self),)
