@@ -27,6 +27,7 @@ from ufl.integral import Integral
 from ufl.form import Form
 from ufl.sorting import cmp_expr, sorted_expr
 from ufl.utils.sorting import canonicalize_metadata, sorted_by_key
+from ufl.algorithms.coordinate_derivative_helpers import attach_coordinate_derivatives, strip_coordinate_derivatives
 import numbers
 
 
@@ -160,7 +161,7 @@ def integral_subdomain_ids(integral):
         error("Invalid domain id %s." % did)
 
 
-def rearrange_integrals_by_single_subdomains(integrals):
+def rearrange_integrals_by_single_subdomains(integrals, do_append_everywhere_integrals):
     """Rearrange integrals over multiple subdomains to single subdomain integrals.
 
     Input:
@@ -196,14 +197,14 @@ def rearrange_integrals_by_single_subdomains(integrals):
     otherwise_integrals = []
     for ev_itg in everywhere_integrals:
         # Restrict everywhere integral to 'otherwise'
-        otherwise_integrals.append(
-            ev_itg.reconstruct(subdomain_id="otherwise"))
+        otherwise_integrals.append(ev_itg.reconstruct(subdomain_id="otherwise"))
 
         # Restrict everywhere integral to each subdomain
         # and append to each integral list
-        for subdomain_id in sorted(single_subdomain_integrals.keys()):
-            single_subdomain_integrals[subdomain_id].append(
-                ev_itg.reconstruct(subdomain_id=subdomain_id))
+        if do_append_everywhere_integrals:
+            for subdomain_id in sorted(single_subdomain_integrals.keys()):
+                single_subdomain_integrals[subdomain_id].append(
+                    ev_itg.reconstruct(subdomain_id=subdomain_id))
 
     if otherwise_integrals:
         single_subdomain_integrals["otherwise"] = otherwise_integrals
@@ -280,11 +281,11 @@ def build_integral_data(integrals):
     return integral_datas
 
 
-def group_form_integrals(form, domains):
+def group_form_integrals(form, domains, do_append_everywhere_integrals=True):
     """Group integrals by domain and type, performing canonical simplification.
 
     :arg form: the :class:`~.Form` to group the integrals of.
-    :arg domains: an iterable of :class:`~.Domain`\s.
+    :arg domains: an iterable of :class:`~.Domain`s.
     :returns: A new :class:`~.Form` with gathered integrands.
     """
     # Group integrals by domain and type
@@ -304,17 +305,43 @@ def group_form_integrals(form, domains):
             # (note: before this call, 'everywhere' is a valid subdomain_id,
             # and after this call, 'otherwise' is a valid subdomain_id)
             single_subdomain_integrals = \
-                rearrange_integrals_by_single_subdomains(ddt_integrals)
+                rearrange_integrals_by_single_subdomains(ddt_integrals, do_append_everywhere_integrals)
 
             for subdomain_id, ss_integrals in sorted_by_key(single_subdomain_integrals):
-                # Accumulate integrands of integrals that share the
-                # same compiler data
-                integrands_and_cds = \
-                    accumulate_integrands_with_same_metadata(ss_integrals)
 
-                for integrand, metadata in integrands_and_cds:
-                    integrals.append(Integral(integrand, integral_type, domain,
-                                              subdomain_id, metadata, None))
+                # strip the coordinate derivatives from all integrals
+                # this yields a list of the form [(coordinate derivative, integral), ...]
+                stripped_integrals_and_coordderivs = strip_coordinate_derivatives(ss_integrals)
+
+                # now group the integrals by the coordinate derivative
+                def calc_hash(cd):
+                    return sum(sum(tuple_elem._ufl_compute_hash_()
+                                   for tuple_elem in tuple_) for tuple_ in cd)
+                coordderiv_integrals_dict = {}
+                for integral, coordderiv in stripped_integrals_and_coordderivs:
+                    coordderivhash = calc_hash(coordderiv)
+                    if coordderivhash in coordderiv_integrals_dict:
+                        coordderiv_integrals_dict[coordderivhash][1].append(integral)
+                    else:
+                        coordderiv_integrals_dict[coordderivhash] = (coordderiv, [integral])
+
+                # cd_integrals_dict is now a dict of the form
+                # { hash: (CoordinateDerivative, [integral, integral, ...]), ... }
+                # we can now put the integrals back together and then afterwards
+                # apply the CoordinateDerivative again
+
+                for cdhash, samecd_integrals in sorted_by_key(coordderiv_integrals_dict):
+
+                    # Accumulate integrands of integrals that share the
+                    # same compiler data
+                    integrands_and_cds = \
+                        accumulate_integrands_with_same_metadata(samecd_integrals[1])
+
+                    for integrand, metadata in integrands_and_cds:
+                        integral = Integral(integrand, integral_type, domain,
+                                            subdomain_id, metadata, None)
+                        integral = attach_coordinate_derivatives(integral, samecd_integrals[0])
+                        integrals.append(integral)
     return Form(integrals)
 
 
