@@ -31,6 +31,7 @@ from ufl.core.expr import ufl_err_str
 from ufl.argument import Argument
 from ufl.coefficient import Coefficient
 from ufl.constantvalue import Zero
+from ufl.algebra import Conj
 
 # Other algorithms:
 from ufl.algorithms.map_integrands import map_integrands
@@ -261,6 +262,11 @@ class PartExtracter(Transformer):
     # Grad is a linear operator
     grad = linear_operator
 
+    # Conj, Real, Imag are linear operators
+    conj = linear_operator
+    real = linear_operator
+    imag = linear_operator
+
     def linear_indexed_type(self, x):
         """Return parts of expression belonging to this indexed
         expression."""
@@ -322,7 +328,7 @@ def compute_form_with_arity(form, arity, arguments=None):
 
     if len(arguments) < arity:
         warning("Form has no parts with arity %d." % arity)
-        return 0*form
+        return 0 * form
 
     # Assuming that the form is not a sum of terms
     # that depend on different arguments, e.g. (u+v)*dx
@@ -350,7 +356,7 @@ def compute_form_arities(form):
         error("compute_form_arities cannot handle parts.")
 
     arities = set()
-    for arity in range(len(arguments)+1):
+    for arity in range(len(arguments) + 1):
 
         # Compute parts with arity "arity"
         parts = compute_form_with_arity(form, arity, arguments)
@@ -492,4 +498,4 @@ def compute_form_adjoint(form, reordered_arguments=None):
     if reordered_v.ufl_function_space() != v.ufl_function_space():
         error("Element mismatch between new and old arguments (test functions).")
 
-    return replace(form, {v: reordered_v, u: reordered_u})
+    return map_integrands(Conj, replace(form, {v: reordered_v, u: reordered_u}))
