@@ -24,8 +24,8 @@
 
 import numbers
 
-from ufl.utils.py23 import as_native_str
-from ufl.utils.py23 import as_native_strings
+from ufl.utils.str import as_native_str
+from ufl.utils.str import as_native_strings
 from ufl.core.ufl_type import attach_operators_from_hash_data
 from ufl.core.ufl_id import attach_ufl_id
 from ufl.corealg.traversal import traverse_unique_terminals
@@ -43,6 +43,7 @@ class AbstractDomain(object):
     and topological dimension.
 
     """
+
     def __init__(self, topological_dimension, geometric_dimension):
         # Validate dimensions
         if not isinstance(geometric_dimension, numbers.Integral):
@@ -64,10 +65,6 @@ class AbstractDomain(object):
         "Return the dimension of the topology of this domain."
         return self._topological_dimension
 
-    def __unicode__(self):
-        # Only in python 2
-        return str(self).decode("utf-8")
-
 
 # TODO: Would it be useful to have a domain representing R^d? E.g. for
 # Expression.
@@ -80,6 +77,7 @@ class AbstractDomain(object):
 @attach_ufl_id
 class Mesh(AbstractDomain):
     """Symbolic representation of a mesh."""
+
     def __init__(self, coordinate_element, ufl_id=None, cargo=None):
         self._ufl_id = self._init_ufl_id(ufl_id)
 
@@ -146,6 +144,7 @@ class Mesh(AbstractDomain):
 @attach_ufl_id
 class MeshView(AbstractDomain):
     """Symbolic representation of a mesh."""
+
     def __init__(self, mesh, topological_dimension, ufl_id=None):
         self._ufl_id = self._init_ufl_id(ufl_id)
 
@@ -195,6 +194,7 @@ class MeshView(AbstractDomain):
 @attach_ufl_id
 class TensorProductMesh(AbstractDomain):
     """Symbolic representation of a mesh."""
+
     def __init__(self, meshes, ufl_id=None):
         self._ufl_id = self._init_ufl_id(ufl_id)
 
@@ -272,7 +272,7 @@ def default_domain(cell):
     if domain is None:
         # Create one and only one affine Mesh with a negative ufl_id
         # to avoid id collision
-        ufl_id = -(len(_default_domains)+1)
+        ufl_id = -(len(_default_domains) + 1)
         domain = affine_mesh(cell, ufl_id=ufl_id)
         _default_domains[cell] = domain
     return domain
