@@ -22,14 +22,11 @@
 # Modified by Marie E. Rognes 2010, 2012
 # Modified by Massimiliano Leoni, 2016
 
-# import six
-from ufl.utils.py23 import as_native_str
-from six.moves import zip
+from ufl.utils.str import as_native_str
 from ufl.log import error
 from ufl.finiteelement.finiteelementbase import FiniteElementBase
 
 
-# @six.python_2_unicode_compatible
 class EnrichedElementBase(FiniteElementBase):
     """The vector sum of several finite element spaces:
 
