@@ -46,11 +46,14 @@ def _sorted_integrals(integrals):
 
     # Group integrals in multilevel dict by keys
     # [domain][integral_type][subdomain_id]
-    integrals_dict = defaultdict(lambda: defaultdict(lambda: defaultdict(list)))
+    integrals_dict = defaultdict(
+        lambda: defaultdict(lambda: defaultdict(list)))
     for integral in integrals:
         d = integral.ufl_domain()
         if d is None:
-            error("Each integral in a form must have a uniquely defined integration domain.")
+            error(
+                "Each integral in a form must have a uniquely defined integration domain."
+            )
         it = integral.integral_type()
         si = integral.subdomain_id()
         integrals_dict[d][it][si] += [integral]
@@ -60,8 +63,9 @@ def _sorted_integrals(integrals):
     # Order integrals canonically to increase signature stability
     for d in sort_domains(integrals_dict):
         for it in sorted(integrals_dict[d]):  # str is sortable
-            for si in sorted(integrals_dict[d][it],
-                             key=lambda x: (type(x).__name__, x)):  # int/str are sortable
+            for si in sorted(
+                    integrals_dict[d][it], key=lambda x: (type(x).__name__, x)
+            ):  # int/str are sortable
                 unsorted_integrals = integrals_dict[d][it][si]
                 # TODO: At this point we could order integrals by
                 #       metadata and integrand, or even add the
@@ -175,17 +179,20 @@ class Form(object):
         # Check that all are equal TODO: don't return more than one if
         # all are equal?
         if not all(domain == domains[0] for domain in domains):
-            error("Calling Form.ufl_domain() is only valid if all integrals share domain.")
+            error(
+                "Calling Form.ufl_domain() is only valid if all integrals share domain."
+            )
         # Return the one and only domain
         return domains[0]
 
     def geometric_dimension(self):
         "Return the geometric dimension shared by all domains and functions in this form."
-        gdims = tuple(set(domain.geometric_dimension()
-                          for domain in self.ufl_domains()))
+        gdims = tuple(
+            set(domain.geometric_dimension() for domain in self.ufl_domains()))
         if len(gdims) != 1:
             error("Expecting all domains and functions in a form "
-                  "to share geometric dimension, got %s." % str(tuple(sorted(gdims))))
+                  "to share geometric dimension, got %s." % str(
+                      tuple(sorted(gdims))))
         return gdims[0]
 
     def domain_numbering(self):
@@ -278,7 +285,9 @@ class Form(object):
             # Allow adding 0 or 0.0 as a no-op, needed for sum([a,b])
             return self
 
-        elif isinstance(other, Zero) and not (other.ufl_shape or other.ufl_free_indices):
+        elif isinstance(
+                other,
+                Zero) and not (other.ufl_shape or other.ufl_free_indices):
             # Allow adding ufl Zero as a no-op, needed for sum([a,b])
             return self
 
@@ -305,7 +314,7 @@ class Form(object):
         "Multiply all integrals in form with constant scalar value."
         # This enables the handy "0*form" or "dt*form" syntax
         if is_scalar_constant_expression(scalar):
-            return Form([scalar*itg for itg in self.integrals()])
+            return Form([scalar * itg for itg in self.integrals()])
         return NotImplemented
 
     def __mul__(self, coefficient):
@@ -344,7 +353,8 @@ class Form(object):
         if args:
             arguments = self.arguments()
             if len(arguments) != len(args):
-                error("Need %d arguments to form(), got %d." % (len(arguments), len(args)))
+                error("Need %d arguments to form(), got %d." % (len(arguments),
+                                                                len(args)))
             repdict.update(zip(arguments, args))
 
         coefficients = kwargs.pop("coefficients")
@@ -386,28 +396,22 @@ class Form(object):
         r = "Form([" + itgs + "])"
         return as_native_str(r)
 
-    def x_repr_latex_(self):  # TODO: This works, but enable when form latex rendering is fixed
-        from ufl.algorithms import ufl2latex
-        return "$$%s$$" % ufl2latex(self)
-
-    def x_repr_png_(self):  # TODO: This works, but enable when form latex rendering is fixed
-        from IPython.lib.latextools import latex_to_png
-        return latex_to_png(self._repr_latex_())
-
     # --- Analysis functions, precomputation and caching of various quantities
 
     def _analyze_domains(self):
         from ufl.domain import join_domains, sort_domains
 
         # Collect unique integration domains
-        integration_domains = join_domains([itg.ufl_domain() for itg in self._integrals])
+        integration_domains = join_domains(
+            [itg.ufl_domain() for itg in self._integrals])
 
         # Make canonically ordered list of the domains
         self._integration_domains = sort_domains(integration_domains)
 
         # TODO: Not including domains from coefficients and arguments
         # here, may need that later
-        self._domain_numbering = dict((d, i) for i, d in enumerate(self._integration_domains))
+        self._domain_numbering = dict(
+            (d, i) for i, d in enumerate(self._integration_domains))
 
     def _analyze_subdomain_data(self):
         integration_domains = self.ufl_domains()
@@ -430,7 +434,9 @@ class Form(object):
                 subdomain_data[domain][it] = sd
             elif sd is not None:
                 if data.ufl_id() != sd.ufl_id():
-                    error("Integrals in form have different subdomain_data objects.")
+                    error(
+                        "Integrals in form have different subdomain_data objects."
+                    )
         self._subdomain_data = subdomain_data
 
     def _analyze_form_arguments(self):
@@ -439,12 +445,12 @@ class Form(object):
         arguments, coefficients = extract_arguments_and_coefficients(self)
 
         # Define canonical numbering of arguments and coefficients
-        self._arguments = tuple(sorted(set(arguments),
-                                       key=lambda x: x.number()))
-        self._coefficients = tuple(sorted(set(coefficients),
-                                          key=lambda x: x.count()))
-        self._coefficient_numbering = dict((c, i) for i,
-                                           c in enumerate(self._coefficients))
+        self._arguments = tuple(
+            sorted(set(arguments), key=lambda x: x.number()))
+        self._coefficients = tuple(
+            sorted(set(coefficients), key=lambda x: x.count()))
+        self._coefficient_numbering = dict(
+            (c, i) for i, c in enumerate(self._coefficients))
 
     def _compute_renumbering(self):
         # Include integration domains and coefficients in renumbering
