@@ -28,7 +28,7 @@ import operator
 
 from ufl.log import error, warning
 from ufl.form import Form
-from ufl.constantvalue import Zero, ScalarValue, as_ufl
+from ufl.constantvalue import Zero, RealValue, ComplexValue, as_ufl
 from ufl.differentiation import VariableDerivative, Grad, Div, Curl, NablaGrad, NablaDiv
 from ufl.tensoralgebra import Transposed, Inner, Outer, Dot, Cross, \
     Determinant, Inverse, Cofactor, Trace, Deviatoric, Skew, Sym
@@ -37,6 +37,7 @@ from ufl.variable import Variable
 from ufl.tensors import as_tensor, as_matrix, as_vector, ListTensor
 from ufl.conditional import EQ, NE, \
     AndCondition, OrCondition, NotCondition, Conditional, MaxValue, MinValue
+from ufl.algebra import Conj, Real, Imag
 from ufl.mathfunctions import Sqrt, Exp, Ln, Erf,\
     Cos, Sin, Tan, Cosh, Sinh, Tanh, Acos, Asin, Atan, Atan2,\
     BesselJ, BesselY, BesselI, BesselK
@@ -47,9 +48,9 @@ from ufl.geometry import SpatialCoordinate, FacetNormal
 from ufl.checks import is_cellwise_constant
 from ufl.domain import extract_domains
 
-
 # --- Basic operators ---
 
+
 def rank(f):
     "UFL operator: The rank of *f*."
     f = as_ufl(f)
@@ -62,6 +63,30 @@ def shape(f):
     return f.ufl_shape
 
 
+# --- Complex operators ---
+
+def conj(f):
+    "UFL operator: The complex conjugate of *f*"
+    f = as_ufl(f)
+    return Conj(f)
+
+
+# Alias because both conj and conjugate are in numpy and we wish to be consistent.
+conjugate = conj
+
+
+def real(f):
+    "UFL operator: The real part of *f*"
+    f = as_ufl(f)
+    return Real(f)
+
+
+def imag(f):
+    "UFL operator: The imaginary part of *f*"
+    f = as_ufl(f)
+    return Imag(f)
+
+
 # --- Elementwise tensor operators ---
 
 def elem_op_items(op_ind, indices, *args):
@@ -72,7 +97,7 @@ def elem_op_items(op_ind, indices, *args):
     def extind(ii):
         return indices + (ii,)
 
-    if len(sh) == len(indices)+1:
+    if len(sh) == len(indices) + 1:
         return [op_ind(extind(i), *args) for i in range(n)]
     else:
         return [elem_op_items(op_ind, extind(i), *args) for i in range(n)]
@@ -119,7 +144,7 @@ def transpose(A):
 
 
 def outer(*operands):
-    "UFL operator: Take the outer product of two or more operands."
+    "UFL operator: Take the outer product of two or more operands. The complex conjugate of the first argument is taken."
     n = len(operands)
     if n == 1:
         return operands[0]
@@ -131,16 +156,16 @@ def outer(*operands):
     a = as_ufl(a)
     b = as_ufl(b)
     if a.ufl_shape == () and b.ufl_shape == ():
-        return a*b
+        return Conj(a) * b
     return Outer(a, b)
 
 
 def inner(a, b):
-    "UFL operator: Take the inner product of *a* and *b*."
+    "UFL operator: Take the inner product of *a* and *b*. The complex conjugate of the second argument is taken."
     a = as_ufl(a)
     b = as_ufl(b)
     if a.ufl_shape == () and b.ufl_shape == ():
-        return a*b
+        return a * Conj(b)
     return Inner(a, b)
 
 
@@ -150,15 +175,15 @@ def _partial_inner(a, b):
     "UFL operator: Take the partial inner product of a and b."
     ar, br = len(a.ufl_shape), len(b.ufl_shape)
     n = min(ar, br)
-    return contraction(a, list(range(n-ar, n-ar+n)), b, list(range(n)))
+    return contraction(a, list(range(n - ar, n - ar + n)), b, list(range(n)))
 
 
 def dot(a, b):
-    "UFL operator: Take the dot product of *a* and *b*."
+    "UFL operator: Take the dot product of *a* and *b*. The complex conjugate of the second argument is taken."
     a = as_ufl(a)
     b = as_ufl(b)
     if a.ufl_shape == () and b.ufl_shape == ():
-        return a*b
+        return a * b
     return Dot(a, b)
 
 
@@ -172,7 +197,7 @@ def contraction(a, a_axes, b, b_axes):
     aii = indices(len(a.ufl_shape))
     bii = indices(len(b.ufl_shape))
     cii = indices(len(ai))
-    shape = [None]*len(ai)
+    shape = [None] * len(ai)
     for i, j in enumerate(ai):
         aii[j] = cii[i]
         shape[i] = ash[j]
@@ -180,7 +205,7 @@ def contraction(a, a_axes, b, b_axes):
         bii[j] = cii[i]
         if shape[i] != bsh[j]:
             error("Shape mismatch in contraction.")
-    s = a[aii]*b[bii]
+    s = a[aii] * b[bii]
     cii = set(cii)
     ii = tuple(i for i in (aii + bii) if i not in cii)
     return as_tensor(s, ii)
@@ -251,7 +276,7 @@ def diag(A):
     # Build matrix row by row
     rows = []
     for i in range(n):
-        row = [0]*n
+        row = [0] * n
         row[i] = A[i] if r == 1 else A[i, i]
         rows.append(row)
     return as_matrix(rows)
@@ -432,7 +457,7 @@ def jump(v, n=None):
             return v('+') - v('-')
         r = len(v.ufl_shape)
         if r == 0:
-            return v('+')*n('+') + v('-')*n('-')
+            return v('+') * n('+') + v('-') * n('-')
         else:
             return dot(v('+'), n('+')) + dot(v('-'), n('-'))
     else:
@@ -449,7 +474,7 @@ def jump(v, n=None):
 def avg(v):
     "UFL operator: Take the average of *v* across a facet."
     v = as_ufl(v)
-    return 0.5*(v('+') + v('-'))
+    return 0.5 * (v('+') + v('-'))
 
 
 def cell_avg(f):
@@ -568,8 +593,10 @@ def Min(x, y):  # TODO: Deprecate this notation?
 def _mathfunction(f, cls):
     f = as_ufl(f)
     r = cls(f)
-    if isinstance(r, (ScalarValue, Zero, int, float)):
+    if isinstance(r, (RealValue, Zero, int, float)):
         return float(r)
+    if isinstance(r, (ComplexValue, complex)):
+        return complex(r)
     return r
 
 
@@ -637,9 +664,13 @@ def atan_2(f1, f2):
     "UFL operator: Take the inverse tangent with two the arguments *f1* and *f2*."
     f1 = as_ufl(f1)
     f2 = as_ufl(f2)
+    if isinstance(f1, (ComplexValue, complex)) or isinstance(f2, (ComplexValue, complex)):
+        raise TypeError('atan_2 is incompatible with complex numbers.')
     r = Atan2(f1, f2)
-    if isinstance(r, (ScalarValue, Zero, int, float)):
+    if isinstance(r, (RealValue, Zero, int, float)):
         return float(r)
+    if isinstance(r, (ComplexValue, complex)):
+        return complex(r)
     return r
 
 
