@@ -18,19 +18,16 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with UFL. If not, see <http://www.gnu.org/licenses/>.
 
-from six.moves import zip
-from six.moves import xrange as range
-
 
 def shape_to_strides(sh):
     "Return a tuple of strides given a shape tuple."
     n = len(sh)
     if not n:
         return ()
-    strides = [None]*n
-    strides[n-1] = 1
-    for i in range(n-1, 0, -1):
-        strides[i-1] = strides[i]*sh[i]
+    strides = [None] * n
+    strides[n - 1] = 1
+    for i in range(n - 1, 0, -1):
+        strides[i - 1] = strides[i] * sh[i]
     return tuple(strides)
 
 
